@@ -8,7 +8,9 @@ from django.core.management.base import BaseCommand
 from django.conf import settings
 
 class Command(BaseCommand):
-    '''Checks that configuration and service files exsist and have not beeen deployed before deploying.'''
+    '''
+    Checks that configuration and service files exsist and have not beeen deployed before deploying
+    '''
 
     help = 'Deploys configuration and services for the application'
 
@@ -16,7 +18,6 @@ class Command(BaseCommand):
         '''
         Deploys configuration and services for the application
         '''
-
         # Check if /etc/conf.d/ directory exists
         if not os.path.exists('/etc/conf.d'):
             os.makedirs('/etc/conf.d')
@@ -25,8 +26,9 @@ class Command(BaseCommand):
 
         # ---------------------------- Update Config Files --------------------------- #
         try:
-            for filename in os.listdir(f'{settings.BASE_DIR}/{project_name}/config_files'):
-                with open(os.path.join(f'{settings.BASE_DIR}/{project_name}/config_files', filename), 'r') as file:
+            file_path = f'{settings.BASE_DIR}/{project_name}/config_files'
+            for filename in os.listdir(file_path):
+                with open(os.path.join(file_path), 'r', encoding='UTF-8') as file:
                     file_content = file.read()
                     file.close()
 
@@ -35,31 +37,32 @@ class Command(BaseCommand):
                     print(script)
 
                 # Update config file to match
-                with open(f'/etc/conf.d/{filename}') as file:
+                with open(f'/etc/conf.d/{filename}', encoding='UTF-8') as file:
                     file_content_old = file.read()
                     file.close()
 
                 if file_content != file_content_old:
-                    with(open(f'/etc/conf.d/{filename}.old', 'w')) as file:
+                    with(open(f'/etc/conf.d/{filename}.old', 'w', encoding='UTF-8')) as file:
                         file.write(file_content_old)
                         file.close()
 
-                    with open(f'/etc/conf.d/{filename}', 'w') as file:
+                    with open(f'/etc/conf.d/{filename}', 'w', encoding='UTF-8') as file:
                         file.write(file_content)
                         file.close()
 
                 print(f'Updated {filename}')
 
-        except Exception as err:
-            print(err)
+        except FileNotFoundError:
+            print('No config_files files found')
 
 
         # --------------------------- Update Service Files --------------------------- #
         services = []
 
         try:
-            for filename in os.listdir(f'{settings.BASE_DIR}/{project_name}/service_files'):
-                with open(os.path.join(f'{settings.BASE_DIR}/{project_name}/service_files', filename), 'r') as file:
+            file_path = f'{settings.BASE_DIR}/{project_name}/service_files'
+            for filename in os.listdir(file_path):
+                with open(os.path.join(file_path), 'r', encoding='UTF-8') as file:
                     file_content = file.read()
                     file.close()
 
@@ -68,24 +71,25 @@ class Command(BaseCommand):
                     print(script)
 
                 # Update service file to match
-                with open(f'/etc/systemd/system/{filename}') as file:
+                with open(f'/etc/systemd/system/{filename}', encoding='UTF-8') as file:
                     file_content_old = file.read()
                     file.close()
 
                 if file_content != file_content_old:
-                    with(open(f'/etc/systemd/system/{filename}.old', 'w')) as file:
+                    file_path="/etc/systemd/system/"
+                    with(open(f'{file_path}{filename}.old', 'w', encoding='UTF-8')) as file:
                         file.write(file_content_old)
                         file.close()
 
-                    with open(f'/etc/systemd/system/{filename}', 'w') as file:
+                    with open(f'/etc/systemd/system/{filename}', 'w', encoding='UTF-8') as file:
                         file.write(file_content)
                         file.close()
 
                 services.append(filename)
                 print(f'Updated {filename}')
 
-        except Exception as err:
-            print(err)
+        except FileNotFoundError:
+            print('No service_files files found')
 
 
         # Reload daemon and start services
@@ -97,5 +101,5 @@ class Command(BaseCommand):
                 os.system(f'systemctl restart {service}')
                 # os.system('systemctl status *')
 
-        except Exception as err:
-            print(err)
+        except SystemError:
+            print('No services found')
